#!/bin/bash
# ffoo test harness
# See LICENSE file for copyright and license details.

. test/include/common.sh

tf_has_files() {
    test -d "$1"               || return 1
    test -e "$1"/* &>/dev/null
    case $? in
        0) return 0 ;;
        1) return 1 ;;
        *) return 0 ;;
    esac
}

tf_enum_tests() {
    find test/scripts -maxdepth 1 -type f -perm /111 | cut -d/ -f3-
}

tf_run_tests() {
    local filter="${1:-.*}"
    local projdir=$PWD
    local artifact_dir="$projdir/test/artifacts"
    local tmpdir datadir results tname tes
    es=0
    for tname in $(tf_enum_tests);
    do
        tf_think "### test start: $tname ###"
        tmpdir=$(mktemp -d)
        datadir="$projdir/test/data/$tname"
        stamp=$(date +artifacts-$tname-%Y%m%d-%H%M%S)
        pushd $tmpdir >/dev/null
            cp -r "$projdir/test/scripts/$tname" .
            tf_has_files "$datadir" && cp -r "$datadir/"* .
            TF_FILTER="$filter" TF_PROJDIR=$projdir ./$tname
            tes=$?
            case $tes in
                0|2)        # ok    | bailout (skipped)
                    true
                    ;;
                *)          # fail  | error
                    mkdir -p "$artifact_dir/$stamp"
                    cp -r $tmpdir/* "$artifact_dir/$stamp"
                    ;;
            esac
            test $tes -gt $es && es=$tes
        popd >/dev/null
        rm -rf $tmpdir
        echo "### test end ($tes): $tname ###"
    done
    return $es
}
