#!/bin/bash

. $TF_PROJDIR/test/include/common.sh

tf_enum_subtests() {
    #
    #
    #
    tf_warn "implement tf_enum_subtests()!"
}

tf_parse_test_metadata() {
    #
    # Parse test meta-data and output a sh code
    #
    # Test header, i.e. all lines before first empty line
    # is searched for meta-data defined like
    #
    #     # key: value
    #
    # and values are converted to /bin/sh assignments that
    # can then be used for eval.
    #
    # Supported keys are `env`, `desc` and `cmd`.  One special
    # value is added called `start_at` that contains number of
    # forst line that is already a body.
    #
    perl -we '
        sub quote {
            my $s = $_[0];
            $s =~ s/\x27/\x27\\\x27\x27/g;
            return "\x27$s\x27";
        }
        sub parse_head {
            #
            # parse header and return meta-data
            #
            my $md = {};
            while (<>) {
                chomp;
                m/^$/ and last;
                m/^# desc: (.*)/ and $$md{desc} = quote($1);
                m/^# cmd: (.*)/ and $$md{cmd} = quote($1);
                m/^# env: (.*)/ and $$md{env} = quote($1);
            }
            $$md{start_at} = $. + 1;
            return $md;
        }
        my $md = parse_head();
        print "$_=$$md{$_}\n" foreach keys %{$md};
    '
}

tf_do_subtest() {
    local name=$1
    if ! eval "$(tf_parse_test_metadata < $name)";
    then
        tf_warn "bad header format";
        return $TF_ES_QUIT
    fi
    local env=$(cat $name.env 2>/dev/null)
    local tcmd="tail -n+$start_at $name | $env $cmd - > $name.result"
    eval "$tcmd"
    diff -u $name.oracle $name.result
}

tf_do_subtests() {
    local filter="${TF_FILTER:-.*}"
    local name es tes
    es=0
    for name in $(tf_enum_subtests | grep -e "$filter");
    do
        tf_think "=== subtest: $name ==="
        tf_do_subtest "$name";
        tes=$?
        test $tes -gt $es && es=$tes
    done
    exit $es
}
